"""AWS Whitelisting MCP Server.

A Model Context Protocol (MCP) server for managing AWS Security Group IP whitelisting.
"""

from awswhitelist.__version__ import __version__

__author__ = "AWS Whitelisting Team"
__all__ = ["__version__"]